package com.gree.mall.manager.controller.workerorder;

import cn.hutool.core.lang.TypeReference;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gree.mall.manager.annotation.ZfireList;
import com.gree.mall.manager.bean.workorder.*;
import com.gree.mall.manager.bean.workorder.DispatchCherVO;
import com.gree.mall.manager.helper.ResponseHelper;
import com.gree.mall.manager.logic.workorder.ChangeOrderLogic;
import com.gree.mall.manager.plus.entity.WebsitDispatch;
import com.gree.mall.manager.utils.CommonUtils;
import com.gree.mall.manager.zfire.bean.ZfireParamBean;
import com.gree.mall.manager.zfire.util.FieldUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

@Slf4j
@RestController
@Api(value = "自动派工配置", tags = {"自动派工配置"})
@RequestMapping(value = "/dispatch", produces = "application/json; charset=utf-8")
public class DispatchController {

    @Autowired
    private ChangeOrderLogic changeOrderLogic;


    @ZfireList
    @PostMapping("/list")
    @ApiOperation(value = "未配置街道-列表")
    public ResponseHelper<Page<DispatchVO>> list(
            @RequestBody ZfireParamBean zfireParamBean
    ) {
        IPage<DispatchVO> orderBaseVOIPage = changeOrderLogic.list(zfireParamBean);
        return ResponseHelper.success(orderBaseVOIPage, new TypeReference<DispatchVO>() {
        });
    }


    @PostMapping("/list/export")
    @ApiOperation(value = "未配置街道-导出")
    public void listExport(@RequestBody ZfireParamBean zfireParamBean,
                           HttpServletRequest request, HttpServletResponse response) throws Exception {
        //1.组装查询条件
        ZfireParamBean zfireParam = FieldUtils.supplyParam(zfireParamBean);
        //2.查询要导出的内容
        IPage<DispatchVO> page = changeOrderLogic.list(zfireParamBean);
        //3.导出
        FieldUtils.exportData(page.getRecords(), zfireParam.getExportFields(), request, response);
    }


    @PostMapping("/save")
    @ApiOperation(value = "未配置街道-配置")
    public ResponseHelper save(@Valid @RequestBody WebsitDispatch websitDispatch) {
        changeOrderLogic.saveOrder(websitDispatch);
        return ResponseHelper.success();
    }


    @ZfireList
    @PostMapping("/listDispatch")
    @ApiOperation(value = "自动派工街道配置-列表")
    public ResponseHelper<Page<WebsitDispatchVO>> listDispatch(
            @RequestBody ZfireParamBean zfireParamBean
    ) {
        IPage<WebsitDispatchVO> orderBaseVOIPage = changeOrderLogic.listDispatch(zfireParamBean);
        return ResponseHelper.success(orderBaseVOIPage, new TypeReference<WebsitDispatchVO>() {
        });
    }


    @PostMapping("/listDispatch/export")
    @ApiOperation(value = "自动派工街道配置-导出")
    public void listDispatchExport(@RequestBody ZfireParamBean zfireParamBean,
                                   HttpServletRequest request, HttpServletResponse response) throws Exception {
        //1.组装查询条件
        ZfireParamBean zfireParam = FieldUtils.supplyParam(zfireParamBean);
        //2.查询要导出的内容
        IPage<WebsitDispatchVO> page = changeOrderLogic.listDispatch(zfireParamBean);
        //3.导出
        FieldUtils.exportData(page.getRecords(), zfireParam.getExportFields(), request, response);
    }


    @PostMapping("/saveDispatch")
    @ApiOperation(value = "自动派工街道配置-新增")
    public ResponseHelper save(@Valid @RequestBody WebsitDispatchAdd websitDispatchAdd) {
        changeOrderLogic.saveDispatch(websitDispatchAdd);
        return ResponseHelper.success();
    }

    @PostMapping("/updateDispatch")
    @ApiOperation(value = "自动派工街道配置-编辑")
    public ResponseHelper updateDispatch(@Valid @RequestBody WebsitDispatch websitDispatch) {
        changeOrderLogic.updateDispatch(websitDispatch);
        return ResponseHelper.success();
    }


    @PostMapping("/delDispatch")
    @ApiOperation(value = "自动派工街道配置-删除")
    public ResponseHelper delDispatch(@ApiParam(value = "id", required = false) @RequestParam List<String> id) {
        changeOrderLogic.delDispatch(id);
        return ResponseHelper.success();
    }


    @GetMapping("/download")
    @ApiOperation("自动派工街道配置-下载")
    public void download(HttpServletResponse response) throws IOException {
        CommonUtils.downloadFile("自动派工配置.xlsx",response);
    }


    @PostMapping("/import")
    @ApiOperation("自动派工街道配置-导入")
    public ResponseHelper importData(@RequestParam MultipartFile file) throws IOException {
        changeOrderLogic.importData(file);
        return ResponseHelper.success();
    }

    @PostMapping("/pList")
    @ApiOperation(value = "省")
    public ResponseHelper<List<DispatchCherVO>> pList(
            @ApiParam(value = "省id", required = false) @RequestParam String pId,
            @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
            @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
            @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
            @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
            @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
            @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
            @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId

    ) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic.pList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/cList")
    @ApiOperation(value = "市")
    public ResponseHelper<List<DispatchCherVO>> cList(
            @ApiParam(value = "省id", required = false) @RequestParam String pId,
            @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
            @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
            @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
            @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
            @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
            @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
            @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId
    ) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic.cList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/aList")
    @ApiOperation(value = "区")
    public ResponseHelper<List<DispatchCherVO>> aList(@ApiParam(value = "省id", required = false) @RequestParam String pId,
                                @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
                                @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
                                @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
                                @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
                                @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
                                @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
                                @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic.aList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/sList")
    @ApiOperation(value = "街道")
    public ResponseHelper<List<DispatchCherVO>> sList(
            @ApiParam(value = "省id", required = false) @RequestParam String pId,
            @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
            @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
            @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
            @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
            @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
            @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
            @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId
    ) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic.sList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }


    @PostMapping("/channel")
    @ApiOperation(value = "工单渠道")
    public ResponseHelper<List<DispatchCherVO>> channel(    @ApiParam(value = "省id", required = false) @RequestParam String pId,
                                   @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
                                   @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
                                   @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
                                   @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
                                   @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
                                   @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
                                   @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic.channel(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);

        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/smallList")
    @ApiOperation(value = "工单类型")
    public ResponseHelper<List<DispatchCherVO>> smallList(@ApiParam(value = "省id", required = false) @RequestParam String pId,
                                    @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
                                    @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
                                    @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
                                    @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
                                    @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
                                    @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
                                    @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic
                .smallList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);

        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/categoryList")
    @ApiOperation(value = "产品大类")
    public ResponseHelper<List<DispatchCherVO>> categoryList(@ApiParam(value = "省id", required = false) @RequestParam String pId,
                                       @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
                                       @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
                                       @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
                                       @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
                                       @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
                                       @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
                                       @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic
                .categoryList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }

    @PostMapping("/sourceList")
    @ApiOperation(value = "工单来源")
    public ResponseHelper sourceList(@ApiParam(value = "省id", required = false) @RequestParam String pId,
                                     @ApiParam(value = "市id", required = false) @RequestParam String cityCode,
                                     @ApiParam(value = "区id", required = false) @RequestParam String areaCode,
                                     @ApiParam(value = "街道id", required = false) @RequestParam String streetCode,
                                     @ApiParam(value = "工单渠道id", required = false) @RequestParam String dictCode,
                                     @ApiParam(value = "工单类型id", required = false) @RequestParam String orderSmallId,
                                     @ApiParam(value = "产品大类id", required = false) @RequestParam String categoryId,
                                     @ApiParam(value = "工单来源id", required = false) @RequestParam String orderSourceId) {
        List<DispatchCherVO> dispatchCherVOS = changeOrderLogic
                .sourceList(pId, cityCode, areaCode, streetCode, dictCode, orderSmallId, categoryId, orderSourceId);
        return ResponseHelper.success(dispatchCherVOS);
    }


}
